"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkInvariantsAndGetConfiguration = exports.fileExists = exports.convertKebabCaseToPascalCase = exports.convertPkgNameToKebabCase = exports.progressEstimator = exports.getCacheDir = exports.clearConsole = exports.clearLine = exports.cleanDist = void 0;
const os_1 = __importDefault(require("os"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = require("path");
const readline_1 = __importDefault(require("readline"));
const find_cache_dir_1 = __importDefault(require("find-cache-dir"));
const progress_estimator_1 = __importDefault(require("progress-estimator"));
const cleanDist = () => fs_extra_1.default.emptyDir('./dist');
exports.cleanDist = cleanDist;
const clearLine = () => {
    readline_1.default.clearLine(process.stdout, 0);
    readline_1.default.cursorTo(process.stdout, 0);
};
exports.clearLine = clearLine;
const clearConsole = () => {
    process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
};
exports.clearConsole = clearConsole;
const getCacheDir = (...pathParts) => {
    const thunk = find_cache_dir_1.default({ name: 'mooli-rollup', create: true, thunk: true });
    // @ts-ignore
    return thunk ? thunk(...pathParts) : path_1.resolve(os_1.default.tmpdir(), ...pathParts);
};
exports.getCacheDir = getCacheDir;
exports.progressEstimator = progress_estimator_1.default({
    storagePath: exports.getCacheDir('progress-estimator'),
    spinner: {
        interval: 180,
        frames: ['⚽️', '⚽️', '⚽️'],
    },
});
const convertPkgNameToKebabCase = (pkgName) => pkgName.replace(/[@!]/g, '').replace(/\//g, '-');
exports.convertPkgNameToKebabCase = convertPkgNameToKebabCase;
const convertKebabCaseToPascalCase = (kebabCase) => kebabCase
    .split('-')
    .map((s) => `${s[0].toUpperCase()}${s.slice(1)}`)
    .join('');
exports.convertKebabCaseToPascalCase = convertKebabCaseToPascalCase;
const fileExists = async (dirPath, fileName) => {
    try {
        const stats = await fs_extra_1.default.stat(path_1.resolve(dirPath, fileName));
        return stats.isFile();
    }
    catch (_a) {
        return false;
    }
};
exports.fileExists = fileExists;
const checkInvariantsAndGetConfiguration = async ({ args, cwd }) => {
    const srcDir = path_1.resolve(cwd, 'src');
    const indexTsExists = await exports.fileExists(srcDir, 'index.ts');
    const watchMode = args[0] === 'watch';
    // ts配置路径
    let tsconfigPath;
    const tsconfigOptionIdx = args.indexOf('--tsconfig');
    if (tsconfigOptionIdx !== -1) {
        tsconfigPath = args[tsconfigOptionIdx + 1];
        try {
            await fs_extra_1.default.readFile(tsconfigPath, 'utf8');
        }
        catch (e) {
            throw new Error(`Cannot read tsconfig at ${tsconfigPath}`);
        }
    }
    let pkgJson;
    try {
        const readPkgJson = await fs_extra_1.default.readFile(path_1.resolve(cwd, 'package.json'), 'utf8');
        pkgJson = JSON.parse(readPkgJson);
    }
    catch (_a) {
        throw Error(`Cannot read package.json at ${path_1.resolve(cwd, 'package.json')}`);
    }
    const pkgJsonName = pkgJson.name;
    const addUmdBuild = args.includes('--addUmdBuild');
    const entryFile = path_1.resolve(srcDir, indexTsExists ? 'index.ts' : 'index.tsx');
    const kebabCasePkgName = exports.convertPkgNameToKebabCase(pkgJsonName);
    const pkgJsonSideEffects = pkgJson.sideEffects;
    const pkgJsonDependencyKeys = pkgJson.dependencies
        ? Object.keys(pkgJson.dependencies)
        : [];
    const pkgJsonPeerDependencyKeys = pkgJson.peerDependencies
        ? Object.keys(pkgJson.peerDependencies)
        : [];
    const pkgJsonUmdGlobalDependencies = pkgJson.umdGlobalDependencies;
    return {
        watchMode,
        tsconfigPath,
        addUmdBuild,
        entryFile,
        kebabCasePkgName,
        pkgJsonSideEffects,
        pkgJsonDependencyKeys,
        pkgJsonPeerDependencyKeys,
        pkgJsonUmdGlobalDependencies
    };
};
exports.checkInvariantsAndGetConfiguration = checkInvariantsAndGetConfiguration;
//# sourceMappingURL=utils.js.map